#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class porous_jump_turb_wall_treatment(Boolean):
    """
    'porous_jump_turb_wall_treatment' child.
    """

    fluent_name = "porous-jump-turb-wall-treatment?"

