#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class confirm_overwrite(Boolean):
    """
    Indicate whether or not to confirm attempts to overwrite existing files.
    """

    fluent_name = "confirm-overwrite?"

