#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class dynamic_mechanism_reduction_expert(Boolean):
    """
    Enable expert options for dynamic mechanism reduction.
    """

    fluent_name = "dynamic-mechanism-reduction-expert"

